<?php
/**
 * Customizer - Color Utils
 * 
 * @package Struninn UI Cards - Digital
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnuicards_digital_customizer_color_options_get')) {
  /**
   * Returns color settings.
   * 
   * @since 1.0.0
   * 
   * @param string $preset              Color preset, one of: 'light', 'dark'. Default: 'light'. 
   * @return array $color_settings      Color settings.
   */
  function struninnuicards_digital_customizer_color_options_get($preset = 'light') {
    $color_settings = [
      'light' => [
        /**
         * Global
         */
        '--struninnuicard-digital-light-primary-color' => [
          'label'   => esc_html_x('Primary Color', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#ff2654'
        ],
        '--struninnuicard-digital-light-secondary-color' => [
          'label'   => esc_html_x('Secondary Color', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#ffc700'
        ],

        /**
         * Box
         */
        '--struninnuicard-digital-light-background-color'     => [
          'label'   => esc_html_x('Box Background', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#ffffff'
        ],
        '--struninnuicard-digital-light-background-alt-color' => [
          'label'   => esc_html_x('Darker Box Background', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#f9f9f9'
        ],

        /**
         * Lines
         */
        '--struninnuicard-digital-light-line-color'    => [
          'label'   => esc_html_x('Line', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#e1e1e1'
        ],

        /**
         * Text
         */
        '--struninnuicard-digital-light-text-color'    => [
          'label'   => esc_html_x('Text', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#22212c'
        ],

        /**
         * Verified Sticker
         */
        '--struninnuicard-digital-light-verified-sticker-background-color' => [
          'label'   => esc_html_x('Verified Sticker Background Color', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#0084ff'
        ],
        '--struninnuicard-digital-light-verified-sticker-icon-color'       => [
          'label'   => esc_html_x('Verified Sticker Icon Color', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#ffffff'
        ]
      ],
      'dark' => [
        /**
         * Global
         */
        '--struninnuicard-digital-dark-primary-color' => [
          'label'   => esc_html_x('Primary Color', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#007eff'
        ],
        '--struninnuicard-digital-dark-secondary-color' => [
          'label'   => esc_html_x('Secondary Color', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#00ffd1'
        ],

        /**
         * Box
         */
        '--struninnuicard-digital-dark-background-color'     => [
          'label'   => esc_html_x('Box Background', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#2b2a3b'
        ],
        '--struninnuicard-digital-dark-background-alt-color' => [
          'label'   => esc_html_x('Darker Box Background', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#21202e'
        ],

        /**
         * Lines
         */
        '--struninnuicard-digital-dark-line-color'    => [
          'label'   => esc_html_x('Line', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#38374b'
        ],

        /**
         * Text
         */
        '--struninnuicard-digital-dark-text-color'    => [
          'label'   => esc_html_x('Text', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#ffffff'
        ],

        /**
         * Verified Sticker
         */
        '--struninnuicard-digital-dark-verified-sticker-background-color' => [
          'label'   => esc_html_x('Verified Sticker Background Color', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#0084ff'
        ],
        '--struninnuicard-digital-dark-verified-sticker-icon-color'       => [
          'label'   => esc_html_x('Verified Sticker Icon Color', '(Customizer) Color Option - Label', 'struninnuicards_digital'),
          'type'    => 'color',
          'default' => '#ffffff'
        ]
      ]
    ];

    return $color_settings[$preset];
  }
}

if (!function_exists('struninnuicards_digital_customizer_color_styles_get')) {
  /**
   * Returns current color style variables.
   * 
   * @since 1.0.0
   * 
   * @return string $color_styles      Current color style variables.
   */
  function struninnuicards_digital_customizer_color_styles_get() {
    $color_presets = ['light', 'dark'];

    $current_color_options = [];

    foreach ($color_presets as $color_preset) {
      $current_color_options = array_merge($current_color_options, struninnuicards_digital_customizer_color_options_get($color_preset));
    }

    $custom_user_colors = get_option('struninnuicards_digital_color', []);

    foreach ($current_color_options as $color_name => $color_data) {
      $user_entered_custom_color = array_key_exists($color_name, $custom_user_colors);

      // if user entered a color for this, use it
      if ($user_entered_custom_color) {
        $color_value = $custom_user_colors[$color_name];
      } else {
      // set color default otherwise
        $color_value = $color_data['default'];
      }
      
      $custom_user_colors[$color_name] = $color_value;
    }

    $color_styles = ':root {';

    foreach ($custom_user_colors as $color_name => $color_value) {
      $color_styles .= $color_name . ': ' . $color_value . ';';
    }

    $color_styles .= '}';

    return $color_styles;
  }
}

?>