<?php
/**
 * Functions - Elementor - Widget
 * 
 * @package Struninn UI Cards - Digital
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!class_exists('StruninnUICards_Elementor_Widget_Digital_Card_V3')) {
  /**
   * Video List Elementor Widget.
   * 
   * @since 1.0.0
   */
  class StruninnUICards_Elementor_Widget_Digital_Card_V3 extends \Elementor\Widget_Base {
    public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);

      wp_register_script('struninnuicards-elementor-widget-digital-card', STRUNINNUICARDS_DIGITAL_URL . 'js/elementor/widget/digital-card/digital-card.js', ['elementor-frontend'], '1.0.0', true);
    }

    public function get_name() {
      return 'struninnuicards_elementor_widget_digital_card_v3';
    }
  
    public function get_title() {
      return esc_html__('Struninn UI Card - Digital V3', 'struninnuicards_digital');
    }
  
    public function get_icon() {
      return 'eicon-info-box';
    }
  
    public function get_categories() {
      return ['struninnuicards'];
    }
  
    public function get_keywords() {
      return ['struninn', 'struninnuicards', 'card', 'digital'];
    }
  
    protected function register_controls() {
      $this->start_controls_section(
        'struninnuicards_digital_card_content',
        [
          'label' => esc_html__('Content', 'struninnuicards_digital'),
          'tab'   => \Elementor\Controls_Manager::TAB_CONTENT
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_theme',
        [
          'label'       => esc_html__('Theme', 'struninnuicards_digital'),
          'type'        => \Elementor\Controls_Manager::SELECT,
          'default'     => 'light',
          'options'     => [
            'light' => esc_html__('Light', 'struninnuicards_digital'),
            'dark'  => esc_html__('Dark', 'struninnuicards_digital')
          ]
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_width',
        [
          'label'       => esc_html__('Width', 'struninnuicards_digital'),
          'description' => esc_html__('Use a value of 0 to let the card auto adjust size.', 'struninnuicards_digital'),
          'type'        => \Elementor\Controls_Manager::NUMBER,
          'min'         => 0,
          'step'        => 1,
          'default'     => 0
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_image',
        [
          'label'   => esc_html__('Image', 'struninnuicards_digital'),
          'type'    => \Elementor\Controls_Manager::MEDIA,
          'default' => [
            'url' => 'sample'
          ]
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_likes_enabled',
        [
          'label'         => esc_html__('Likes Display', 'struninnuicards_digital'),
          'type'          => \Elementor\Controls_Manager::SWITCHER,
          'return_value'  => 'yes',
          'default'       => 'yes'
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_likes_text',
        [
          'label'       => esc_html__('Likes Count', 'struninnuicards_digital'),
          'type'        => \Elementor\Controls_Manager::TEXT,
          'input_type'  => 'text',
          'default'     => '22'
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_countdown_enabled',
        [
          'label'         => esc_html__('Countdown Display', 'struninnuicards_digital'),
          'type'          => \Elementor\Controls_Manager::SWITCHER,
          'return_value'  => 'yes',
          'default'       => 'yes'
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_countdown_target_date',
        [
          'label'       => esc_html__('Countdown Target Date', 'struninnuicards_digital'),
          'type'        => \Elementor\Controls_Manager::DATE_TIME,
          'default'     => (new DateTime('tomorrow'))->format('Y-m-d H:i')
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_title',
        [
          'label'       => esc_html__('Title', 'struninnuicards_digital'),
          'type'        => \Elementor\Controls_Manager::TEXT,
          'input_type'  => 'text',
          'default'     => 'Social Blockz'
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_title_link',
        [
          'label'       => esc_html__('Title Link', 'struninnuicards_digital'),
          'type'        => \Elementor\Controls_Manager::URL,
          'options'     => false,
          'default'     => [
            'url' => '#'
          ]
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_user_image',
        [
          'label'   => esc_html__('User Image', 'struninnuicards_digital'),
          'type'    => \Elementor\Controls_Manager::MEDIA,
          'default' => [
            'url' => 'sample'
          ]
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_user_verified',
        [
          'label'         => esc_html__('User Verified', 'struninnuicards_digital'),
          'type'          => \Elementor\Controls_Manager::SWITCHER,
          'return_value'  => 'yes',
          'default'       => 'yes'
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_details_title',
        [
          'label'       => esc_html__('Details Title', 'struninnuicards_digital'),
          'type'        => \Elementor\Controls_Manager::TEXT,
          'input_type'  => 'text',
          'default'     => 'CURRENT BID'
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_details_text',
        [
          'label'       => esc_html__('Details Text', 'struninnuicards_digital'),
          'type'        => \Elementor\Controls_Manager::TEXT,
          'input_type'  => 'text',
          'default'     => '90.55 U$D'
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_share_facebook_enabled',
        [
          'label'         => esc_html__('Facebook Share', 'struninnuicards_digital'),
          'type'          => \Elementor\Controls_Manager::SWITCHER,
          'return_value'  => 'yes',
          'default'       => 'yes'
        ]
      );

      $this->add_control(
        'struninnuicards_digital_card_share_x_enabled',
        [
          'label'         => esc_html__('X Share', 'struninnuicards_digital'),
          'type'          => \Elementor\Controls_Manager::SWITCHER,
          'return_value'  => 'yes',
          'default'       => 'yes'
        ]
      );

      $this->end_controls_section();
    }
  
    protected function render() {
      $settings = $this->get_settings_for_display();

      $args = [
        'theme'                   => $settings['struninnuicards_digital_card_theme'],
        'width'                   => $settings['struninnuicards_digital_card_width'],
        'image_url'               => $settings['struninnuicards_digital_card_image']['url'],
        'likes_enabled'           => $settings['struninnuicards_digital_card_likes_enabled'] === 'yes',
        'likes_text'              => $settings['struninnuicards_digital_card_likes_text'],
        'countdown_enabled'       => $settings['struninnuicards_digital_card_countdown_enabled'] === 'yes',
        'countdown_target_date'   => $settings['struninnuicards_digital_card_countdown_target_date'],
        'title'                   => $settings['struninnuicards_digital_card_title'],
        'title_link'              => $settings['struninnuicards_digital_card_title_link']['url'],
        'user_image_url'          => $settings['struninnuicards_digital_card_user_image']['url'],
        'user_verified'           => $settings['struninnuicards_digital_card_user_verified'] === 'yes',
        'details_title'           => $settings['struninnuicards_digital_card_details_title'],
        'details_text'            => $settings['struninnuicards_digital_card_details_text'],
        'share_facebook_enabled'  => $settings['struninnuicards_digital_card_share_facebook_enabled'] === 'yes',
        'share_x_enabled'         => $settings['struninnuicards_digital_card_share_x_enabled'] === 'yes'
      ];
    
      struninnuicards_digital_template_card_v3($args);
    }

    public function get_script_depends() {
      return ['struninnuicards-elementor-widget-digital-card'];
    }
  }
}

?>