<?php
/**
 * Functions - Template - Card V2
 * 
 * @package Struninn UI Cards - Digital
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnuicards_digital_template_card_v2_args_default_get')) {
  /**
   * Returns card v2 template default args.
   * 
   * @since 1.0.0
   * 
   * @return array $card_args_default        Default card v2 template args.
   */
  function struninnuicards_digital_template_card_v2_args_default_get() {
    $card_args_default = [
      'theme'                   => 'light',
      'width'                   => 0,
      'image_url'               => 'sample',
      'likes_enabled'           => true,
      'likes_text'              => '22',
      'countdown_enabled'       => true,
      'countdown_target_date'   => (new DateTime('tomorrow'))->format('Y-m-d H:i'),
      'title'                   => 'The Molten Heart',
      'title_link'              => '#',
      'user_image_url'          => 'sample',
      'user_title'              => 'AUTHOR',
      'user_name'               => '@JackieJ',
      'user_name_link'          => '#',
      'user_verified'           => true,
      'details_right_title'     => 'STOCK',
      'details_right_text'      => '100/450',
      'footer_left_title'       => 'SHARE:',
      'share_facebook_enabled'  => true,
      'share_x_enabled'         => true
    ];

    return $card_args_default;
  }
}

if (!function_exists('struninnuicards_digital_template_card_v2_get')) {
  /**
   * Returns card v2 template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type string $theme                        Card color scheme, one of: 'light', 'dark'.
   *   @type int    $width                        Card width, a value of 0 to lets the card auto adjust size.
   *   @type string $image_url                    Card image URL. A value of 'sample' shows an example of how the image will display.
   *   @type bool   $likes_enabled                True to display likes tag, false otherwise.
   *   @type string $likes_text                   Likes tag text.
   *   @type bool   $countdown_enabled            True to display countdown tag, false otherwise.
   *   @type string $countdown_target_date        Countdown target date.
   *   @type string $title                        Title.
   *   @type string $title_link                   Title link URL.
   *   @type string $user_image_url               User image URL. A value of 'sample' shows an example of how the image will display.
   *   @type string $user_title                   User title.
   *   @type string $user_name                    User name.
   *   @type string $user_name_link               User name link URL.
   *   @type bool   $user_verified                True to display verified user sticker, false otherwise.
   *   @type string $details_right_title          Details right title.
   *   @type string $details_right_text           Details right text.
   *   @type string $footer_left_title            Footer left title.
   *   @type bool   $share_facebook_enabled       True to display facebook share link, false otherwise.
   *   @type bool   $share_x_enabled              True to display x share link, false otherwise.
   * }
   * @return string $template                     Card v2 HTML template.
   */
  function struninnuicards_digital_template_card_v2_get($args = []) {
    $defaults = struninnuicards_digital_template_card_v2_args_default_get();

    $options = array_merge($defaults, $args);

    $card_image_classes = $options['image_url'] === 'sample' ? ' card__image_sample' : '';

    ob_start();

  ?>
    <!-- STRUNINN UI CARD DIGITAL -->
    <div class="struninnuicard-digital struninnuicard-digital_theme-<?php echo esc_attr($options['theme']); ?>">
      <!-- CARD -->
      <div class="card"<?php if ($options['width'] !== 0) : ?> style="max-width: <?php echo esc_attr($options['width']); ?>px;"<?php endif; ?>>
        <!-- CARD BODY -->
        <div class="card__body">
        <?php if ($options['image_url'] !== '') : ?>
          <!-- CARD IMAGE CONTAINER -->
          <div class="card__image-container<?php echo esc_attr($card_image_classes); ?>">
          <?php if ($options['image_url'] !== 'sample') : ?>
            <img class="card__image" src="<?php echo esc_url($options['image_url']); ?>" alt="">
          <?php endif; ?>
          <?php

            if ($options['countdown_enabled']) {
              /**
               * Card Tag
               */
              struninnuicards_digital_template_tag([
                'target_date' => $options['countdown_target_date'],
                'icon'        => 'watch',
                'position'    => 'bottom left'
              ]);
            }
          
          ?>
          </div>
          <!-- /CARD IMAGE CONTAINER -->
        <?php endif; ?>

          <!-- CARD BODY CONTENT -->
          <div class="card__body-content">
            <!-- CARD ROW -->
            <div class="card__row">
            <?php if (array_key_exists('title_link', $options) && $options['title_link'] !== '') : ?>
              <a class="card__link" href="<?php echo esc_url($options['title_link']); ?>">
            <?php endif; ?>
                <h2 class="card__title"><?php echo esc_html($options['title']); ?></h2>
            <?php if (array_key_exists('title_link', $options) && $options['title_link'] !== '') : ?>
              </a>
            <?php endif; ?>
            <?php

              if ($options['likes_enabled']) {
                /**
                 * Card Tag
                 */
                struninnuicards_digital_template_tag([
                  'text'  => $options['likes_text'],
                  'icon'  => 'heart'
                ]);
              }

            ?>
            </div>
            <!-- /CARD ROW -->
          </div>
          <!-- /CARD BODY CONTENT -->
        </div>
        <!-- /CARD BODY -->

        <!-- CARD FOOTER -->
        <div class="card-footer">
          <!-- CARD ROW -->
          <div class="card__row">
            <div class="card__column">
            <?php

              /**
               * User Avatar
               */
              struninnuicards_digital_template_user_avatar([
                'image_url' => $options['user_image_url'],
                'small'     => true,
                'verified'  => $options['user_verified']
              ]);

            ?>

              <div class="card__metadata">
              <?php if (array_key_exists('user_title', $options) && $options['user_title'] !== '') : ?>
                <p class="card__text card__text_small"><?php echo esc_html($options['user_title']); ?></p>
              <?php endif; ?>
              
              <?php if (array_key_exists('user_name_link', $options) && $options['user_name_link'] !== '') : ?>
                <a class="card__link" href="<?php echo esc_url($options['user_name_link']); ?>">
              <?php endif; ?>
                  <p class="card__text card__text_bold"><?php echo esc_html($options['user_name']); ?></p>
              <?php if (array_key_exists('user_name_link', $options) && $options['user_name_link'] !== '') : ?>
                </a>
              <?php endif; ?>
              </div>
            </div>

            <div class="card__column">
              <div class="card__metadata">
              <?php if (array_key_exists('details_right_title', $options) && $options['details_right_title'] !== '') : ?>
                <p class="card__text card__text_small"><?php echo esc_html($options['details_right_title']); ?></p>
              <?php endif; ?>

              <?php if (array_key_exists('details_right_text', $options) && $options['details_right_text'] !== '') : ?>
                <p class="card__text card__text_bold"><?php echo esc_html($options['details_right_text']); ?></p>
              <?php endif; ?>
              </div>
            </div>
          </div>
          <!-- /CARD ROW -->
        </div>
        <!-- /CARD FOOTER -->

      <?php if (($options['footer_left_title'] !== '') || $options['share_facebook_enabled'] || $options['share_x_enabled']) : ?>
        <!-- CARD FOOTER -->
        <div class="card-footer card-footer_darker card-footer_small">
          <!-- CARD ROW -->
          <div class="card__row">
            <div class="card__column">
              <div class="card__metadata">
                <p class="card__text card__text_small"><?php echo esc_html($options['footer_left_title']); ?></p>
              </div>
            </div>

            <div class="card__column">
              <div class="card__metadata">
              <?php

                if ($options['share_facebook_enabled'] || $options['share_x_enabled']) {
                  $social_links_args = [
                    'social_links' => [
                      'facebook'  => $options['share_facebook_enabled'],
                      'x'         => $options['share_x_enabled']
                    ],
                    'share_text'  => $options['title']
                  ];

                  if ($options['title_link'] !== '#') {
                    $social_links_args['share_url'] = $options['title_link'];
                  }

                  /**
                   * Social Links
                   */
                  struninnuicards_digital_template_social_links($social_links_args);
                }

              ?>
              </div>
            </div>
          </div>
          <!-- /CARD ROW -->
        </div>
        <!-- /CARD FOOTER -->
      <?php endif; ?>
      </div>
      <!-- /CARD -->
    </div>
    <!-- /STRUNINN UI CARD DIGITAL -->
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_digital_template_card_v2')) {
  /**
   * Prints card v2 template.
   * 
   * @since 1.0.0
   * 
   * @param array   $args           Card template args.
   */
  function struninnuicards_digital_template_card_v2($args = []) {
    $template = struninnuicards_digital_template_card_v2_get($args);

    $template_allowed_html = [
      'div' => [
        'class'             => [],
        'style'             => [],
        'data-target-date'  => []
      ],
      'img' => [
        'class' => [],
        'src'   => [],
        'alt'   => []
      ],
      'h2' => [
        'class' => []
      ],
      'p' => [
        'class' => []
      ],
      'a' => [
        'class'   => [],
        'href'    => [],
        'target'  => []
      ],
      'svg' => [
        'class' => []
      ],
      'use' => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}