<?php
/**
 * Functions - Template - Card V4
 * 
 * @package Struninn UI Cards - Digital
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnuicards_digital_template_card_v4_args_default_get')) {
  /**
   * Returns card v4 template default args.
   * 
   * @since 1.0.0
   * 
   * @return array $card_args_default        Default card v4 template args.
   */
  function struninnuicards_digital_template_card_v4_args_default_get() {
    $card_args_default = [
      'theme'                   => 'light',
      'width'                   => 0,
      'image_url'               => 'sample',
      'likes_enabled'           => true,
      'likes_text'              => '22',
      'countdown_enabled'       => true,
      'countdown_target_date'   => (new DateTime('tomorrow'))->format('Y-m-d H:i'),
      'title'                   => 'Canary\'s Kitchen',
      'title_link'              => '#',
      'user_image_url'          => 'sample',
      'user_name'               => '@DexterStark',
      'user_name_link'          => '#',
      'user_verified'           => true,
      'details_title'           => '90.55 U$D',
      'details_text'            => 'CURRENT BID',
      'button_style'            => 'solid',
      'button_text'             => 'Bid!',
      'button_link'             => '#',
      'footer_left_title'       => 'ENDING IN',
      'footer_right_title'      => 'SHARE',
      'share_facebook_enabled'  => true,
      'share_x_enabled'         => true
    ];

    return $card_args_default;
  }
}

if (!function_exists('struninnuicards_digital_template_card_v4_get')) {
  /**
   * Returns card v4 template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type string $theme                        Card color scheme, one of: 'light', 'dark'.
   *   @type int    $width                        Card width, a value of 0 to lets the card auto adjust size.
   *   @type string $image_url                    Card image URL. A value of 'sample' shows an example of how the image will display.
   *   @type bool   $likes_enabled                True to display likes tag, false otherwise.
   *   @type string $likes_text                   Likes tag text.
   *   @type bool   $countdown_enabled            True to display countdown tag, false otherwise.
   *   @type string $countdown_target_date        Countdown target date.
   *   @type string $title                        Title.
   *   @type string $title_link                   Title link URL.
   *   @type string $user_image_url               User image URL. A value of 'sample' shows an example of how the image will display.
   *   @type string $user_name                    User name.
   *   @type string $user_name_link               User name link URL.
   *   @type bool   $user_verified                True to display verified user sticker, false otherwise.
   *   @type string $details_title                Details title.
   *   @type string $details_text                 Details text.
   *   @type string $button_style                 Button style, one of: 'solid', 'outline'.
   *   @type string $button_text                  Button text.
   *   @type string $footer_left_title            Footer left title.
   *   @type string $footer_right_title           Footer right title.
   *   @type bool   $share_facebook_enabled       True to display facebook share link, false otherwise.
   *   @type bool   $share_x_enabled              True to display x share link, false otherwise.
   * }
   * @return string $template                     Card v4 HTML template.
   */
  function struninnuicards_digital_template_card_v4_get($args = []) {
    $defaults = struninnuicards_digital_template_card_v4_args_default_get();

    $options = array_merge($defaults, $args);

    $card_image_classes = $options['image_url'] === 'sample' ? ' card__image_sample' : '';

    ob_start();

  ?>
    <!-- STRUNINN UI CARD DIGITAL -->
    <div class="struninnuicard-digital struninnuicard-digital_theme-<?php echo esc_attr($options['theme']); ?>">
      <!-- CARD -->
      <div class="card"<?php if ($options['width'] !== 0) : ?> style="max-width: <?php echo esc_attr($options['width']); ?>px;"<?php endif; ?>>
        <!-- CARD BODY -->
        <div class="card__body">
        <?php if ($options['image_url'] !== '') : ?>
          <!-- CARD IMAGE CONTAINER -->
          <div class="card__image-container<?php echo esc_attr($card_image_classes); ?>">
          <?php if ($options['image_url'] !== 'sample') : ?>
            <img class="card__image" src="<?php echo esc_url($options['image_url']); ?>" alt="">
          <?php endif; ?>
          <?php

            if ($options['likes_enabled']) {
              /**
               * Card Tag
               */
              struninnuicards_digital_template_tag([
                'text'      => $options['likes_text'],
                'icon'      => 'heart',
                'position'  => 'top right'
              ]);
            }

            /**
             * User Avatar
             */
            struninnuicards_digital_template_user_avatar([
              'image_url' => $options['user_image_url'],
              'bordered'  => true,
              'verified'  => $options['user_verified']
            ]);
          
          ?>
          </div>
          <!-- /CARD IMAGE CONTAINER -->
        <?php endif; ?>

          <!-- CARD BODY CONTENT -->
          <div class="card__body-content card__body-content_spaced">
            <!-- CARD ROW -->
            <div class="card__row">
              <div class="card__column">
                <div class="card__metadata card__metadata_spaced">
                  <?php if (array_key_exists('title_link', $options) && $options['title_link'] !== '') : ?>
                    <div>
                    <a class="card__link" href="<?php echo esc_url($options['title_link']); ?>">
                  <?php endif; ?>
                      <h2 class="card__title"><?php echo esc_html($options['title']); ?></h2>
                  <?php if (array_key_exists('title_link', $options) && $options['title_link'] !== '') : ?>
                    </a>
                    </div>
                  <?php endif; ?>

                  <?php if (array_key_exists('user_name_link', $options) && $options['user_name_link'] !== '') : ?>
                    <div>
                    <a class="card__link" href="<?php echo esc_url($options['user_name_link']); ?>">
                  <?php endif; ?>
                      <p class="card__text card__text_highlighted"><?php echo esc_html($options['user_name']); ?></p>
                  <?php if (array_key_exists('user_name_link', $options) && $options['user_name_link'] !== '') : ?>
                    </a>
                    </div>
                  <?php endif; ?>
                </div>
              </div>
            </div>
            <!-- /CARD ROW -->

            <!-- CARD ROW -->
            <div class="card__row">
              <div class="card__column">
                <div class="card__metadata">
                  <p class="card__text card__text_medium card__text_bold"><?php echo esc_html($options['details_title']); ?></p>
                  <p class="card__text card__text_small"><?php echo esc_html($options['details_text']); ?></p>
                </div>
              </div>

              <div class="card__column">
                <a class="card__button card__button_<?php echo esc_attr($options['button_style']); ?>" href="<?php echo esc_url($options['button_link']); ?>"><?php echo esc_html($options['button_text']); ?></a>
              </div>
            </div>
            <!-- /CARD ROW -->
          </div>
          <!-- /CARD BODY CONTENT -->
        </div>
        <!-- /CARD BODY -->

      <?php if (($options['footer_left_title'] !== '') || $options['countdown_enabled'] || ($options['footer_right_title'] !== '') || $options['share_facebook_enabled'] || $options['share_x_enabled']) : ?>
        <!-- CARD FOOTER -->
        <div class="card-footer card-footer_darker card-footer_small">
          <!-- CARD ROW -->
          <div class="card__row">
            <div class="card__column">
              <div class="card__metadata">
                <p class="card__text card__text_small"><?php echo esc_html($options['footer_left_title']); ?></p>
              <?php if ($options['countdown_enabled']) : ?>
                <div class="struninn-countdown" data-target-date="<?php echo esc_attr($options['countdown_target_date']); ?>">
                  <p class="card__text card__text_bold countdown__text"></p>
                </div>
              <?php endif; ?>
              </div>
            </div>

            <div class="card__column">
              <div class="card__metadata">
                <p class="card__text card__text_small"><?php echo esc_html($options['footer_right_title']); ?></p>
              <?php

                if ($options['share_facebook_enabled'] || $options['share_x_enabled']) {
                  $social_links_args = [
                    'social_links' => [
                      'facebook'  => $options['share_facebook_enabled'],
                      'x'         => $options['share_x_enabled']
                    ],
                    'share_text'  => $options['title']
                  ];

                  if ($options['title_link'] !== '#') {
                    $social_links_args['share_url'] = $options['title_link'];
                  }

                  /**
                   * Social Links
                   */
                  struninnuicards_digital_template_social_links($social_links_args);
                }

              ?>
              </div>
            </div>
          </div>
          <!-- /CARD ROW -->
        </div>
        <!-- /CARD FOOTER -->
      <?php endif; ?>
      </div>
      <!-- /CARD -->
    </div>
    <!-- /STRUNINN UI CARD DIGITAL -->
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_digital_template_card_v4')) {
  /**
   * Prints card v4 template.
   * 
   * @since 1.0.0
   * 
   * @param array   $args           Card template args.
   */
  function struninnuicards_digital_template_card_v4($args = []) {
    $template = struninnuicards_digital_template_card_v4_get($args);

    $template_allowed_html = [
      'div' => [
        'class'             => [],
        'style'             => [],
        'data-target-date'  => []
      ],
      'img' => [
        'class' => [],
        'src'   => [],
        'alt'   => []
      ],
      'h2' => [
        'class' => []
      ],
      'p' => [
        'class' => []
      ],
      'a' => [
        'class'   => [],
        'href'    => [],
        'target'  => []
      ],
      'svg' => [
        'class' => []
      ],
      'use' => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}