<?php
/**
 * Functions - Template - Part
 * 
 * @package Struninn UI Cards - Digital
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnuicards_digital_template_user_avatar_get')) {
  /**
   * Returns user avatar template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type string $image_url        Avatar image URL.
   *   @type bool   $small            True to display a small avatar, false otherwise.
   *   @type bool   $bordered         True to display an avatar border, false otherwise.
   *   @type bool   $verified         True to display verified user sticker, false otherwise.
   * }
   * @return string $template         User avatar HTML template.
   */
  function struninnuicards_digital_template_user_avatar_get($args = []) {
    ob_start();

    $defaults = [
      'image_url' => '',
      'small'     => false,
      'bordered'  => false,
      'verified'  => false
    ];

    $options = array_merge($defaults, $args);

    $wrapper_classes = [
      'user__image-container'
    ];

    $verified_sticker_wrapper_classes = [
      'verified-sticker'
    ];

    if ($options['small']) {
      $wrapper_classes[] = 'user__image-container_small';
      $verified_sticker_wrapper_classes[] = 'verified-sticker_small';
    }

    if ($options['bordered']) {
      $wrapper_classes[] = 'user__image-container_bordered';
    }

    if ($options['image_url'] === 'sample') {
      $wrapper_classes[] = 'card__image_sample';
    }

  ?>
  <?php if ($options['image_url'] != '') : ?>
    <div class="<?php echo esc_attr(implode(' ', $wrapper_classes)); ?>">
    <?php if ($options['image_url'] !== 'sample') : ?>
      <img class="user__image" src="<?php echo esc_url($options['image_url']); ?>" alt="">
    <?php endif; ?>
    <?php if ($options['verified']) : ?>
      <div class="<?php echo esc_attr(implode(' ', $verified_sticker_wrapper_classes)); ?>">
      <?php

        /**
         * Icon
         */
        struninnuicards_digital_template_icon([
          'additional_wrapper_classes'  => 'verified-sticker__icon',
          'icon'                        => 'tick'
        ]);

      ?>
      </div>
    <?php endif; ?>
    </div>
  <?php endif; ?>
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_digital_template_user_avatar')) {
  /**
   * Prints user avatar template.
   * 
   * @since 1.0.0
   */
  function struninnuicards_digital_template_user_avatar($args = []) {
    $template = struninnuicards_digital_template_user_avatar_get($args);

    $template_allowed_html = [
      'div' => [
        'class' => []
      ],
      'img' => [
        'class' => [],
        'src'   => [],
        'alt'   => []
      ],
      'svg' => [
        'class' => []
      ],
      'use' => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}

if (!function_exists('struninnuicards_digital_template_tag_get')) {
  /**
   * Returns tag template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type string $text             Tag text.
   *   @type string $target_date      Target date for countdown.
   *   @type string $position         Tag position relative to container, accepted values: 'top', 'bottom', 'center', 'left', 'right' (i.e. 'bottom center').
   *   @type bool   $small            True to display a small tag, false otherwise.
   *   @type bool   $border           True to display a tag border, false otherwise.
   *   @type bool   $padding          True to display a tag padding, false otherwise.
   * }
   * @return string $template         Tag HTML template.
   */
  function struninnuicards_digital_template_tag_get($args = []) {
    ob_start();

    $defaults = [];

    $options = array_merge($defaults, $args);

    $wrapper_classes = [
      'tag'
    ];

    $position_class = '';

    if (array_key_exists('position', $options)) {
      $position_directions = explode(' ', $options['position']);
      $position_class = trim(array_reduce($position_directions, function ($carry, $item) { $carry .= 'tag_' . $item . ' '; return $carry; }));
      $wrapper_classes[] = $position_class;
    }

    if (array_key_exists('border', $options)) {
      if ($options['border'] === false) {
        $wrapper_classes[] = 'tag_no-border';
      }
    }

    if (array_key_exists('padding', $options)) {
      if ($options['padding'] === false) {
        $wrapper_classes[] = 'tag_no-padding';
      }
    }

    if (array_key_exists('small', $options)) {
      if ($options['small'] === true) {
        $wrapper_classes[] = 'tag_small';
      }
    }

    if (array_key_exists('target_date', $options)) {
      $wrapper_classes[] = 'struninn-countdown';
    }

  ?>
    <!-- TAG -->
    <div
      class="<?php echo esc_attr(implode(' ', $wrapper_classes)); ?>"
      <?php if (array_key_exists('target_date', $options)) : ?>data-target-date="<?php echo esc_attr($options['target_date']); ?>"<?php endif; ?>
    >
    <?php

      if (array_key_exists('icon', $options)) {
        /**
         * Icon
         */
        struninnuicards_digital_template_icon([
          'additional_wrapper_classes'  => 'tag__icon',
          'icon'                        => $options['icon'],
          'gradient'                    => true
        ]);
      }
      
    ?>
    
    <?php if (array_key_exists('text', $options)) : ?>
      <p class="tag__text"><?php echo esc_html($options['text']); ?></p>
    <?php elseif (array_key_exists('target_date', $options)) : ?>
      <p class="tag__text countdown__text"></p>
    <?php endif; ?>
    </div>
    <!-- /TAG -->
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_digital_template_tag')) {
  /**
   * Prints tag template.
   * 
   * @since 1.0.0
   */
  function struninnuicards_digital_template_tag($args = []) {
    $template = struninnuicards_digital_template_tag_get($args);

    $template_allowed_html = [
      'div' => [
        'class'             => [],
        'data-target-date'  => []
      ],
      'p' => [
        'class' => []
      ],
      'svg' => [
        'class' => []
      ],
      'use' => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}

if (!function_exists('struninnuicards_digital_template_icon_get')) {
  /**
   * Returns icon template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type string $additional_wrapper_classes       Classes to add to the wrapper.
   *   @type bool   $gradient                         True to display a color gradient, false otherwise.
   * }
   * @return string $template                         Icon HTML template.
   */
  function struninnuicards_digital_template_icon_get($args = []) {
    ob_start();

    $defaults = [
      'gradient'                    => false,
      'additional_wrapper_classes'  => false
    ];

    $options = array_merge($defaults, $args);

    $wrapper_classes = [
      'icon_'. $options['icon']
    ];

    if ($options['gradient']) {
      $wrapper_classes[] = 'icon_gradient';
    }

    if ($options['additional_wrapper_classes']) {
      $wrapper_classes[] = $options['additional_wrapper_classes'];
    }

  ?>
    <!-- ICON -->
    <svg class="<?php echo esc_attr(implode(' ', $wrapper_classes)); ?>">
      <use href="#svg-<?php echo esc_attr($options['icon']); ?>"></use>
    </svg>
    <!-- ICON -->
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_digital_template_icon')) {
  /**
   * Prints icon template.
   * 
   * @since 1.0.0
   */
  function struninnuicards_digital_template_icon($args = []) {
    $template = struninnuicards_digital_template_icon_get($args);

    $template_allowed_html = [
      'svg' => [
        'class' => []
      ],
      'use' => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}

if (!function_exists('struninnuicards_digital_template_social_links_get')) {
  /**
   * Returns social links template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type array $social_links {
   *     @type bool $facebook           True to display facebook share, false otherwise.
   *     @type bool $x                  True to display x share, false otherwise.
   *   }
   *   @type string   $share_text       Share text.
   *   @type string   $share_url        Share URL.
   * }
   * @return string $template           Social links HTML template.
   */
  function struninnuicards_digital_template_social_links_get($args = []) {
    ob_start();

    $defaults = [
      'social_links'  => [
        'facebook'  => true,
        'x'         => true
      ]
    ];

    $options = array_merge($defaults, $args);

  ?>
    <div class="social__links">
    <?php

      foreach ($options['social_links'] as $social_network_name => $social_network_enabled) {
        if ($social_network_enabled) {
          $social_link_args = [
            'name'  => $social_network_name
          ];

          if (array_key_exists('share_text', $options)) {
            $social_link_args['share_text'] = $options['share_text'];
          }

          if (array_key_exists('share_url', $options)) {
            $social_link_args['share_url'] = $options['share_url'];
          }

          /**
           * Social Link
           */
          struninnuicards_digital_template_social_link($social_link_args);
        }
      }

    ?>
    </div>
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_digital_template_social_links')) {
  /**
   * Prints social links template.
   * 
   * @since 1.0.0
   */
  function struninnuicards_digital_template_social_links($args = []) {
    $template = struninnuicards_digital_template_social_links_get($args);

    $template_allowed_html = [
      'div' => [
        'class' => []
      ],
      'a' => [
        'class'   => [],
        'href'    => [],
        'target'  => []
      ],
      'svg' => [
        'class' => []
      ],
      'use' => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}

if (!function_exists('struninnuicards_digital_template_social_link_get')) {
  /**
   * Returns social link template.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type string   $name             Icon name.
   *   @type string   $share_text       Share text.
   *   @type string   $share_url        Share URL.
   * }
   * @return string $template           Social link HTML template.
   */
  function struninnuicards_digital_template_social_link_get($args = []) {
    ob_start();

    global $wp;

    $current_page_url = home_url($wp->request);

    $defaults = [
      'share_text'  => '',
      'share_url'   => $current_page_url
    ];

    $options = array_merge($defaults, $args);

    if ($options['share_url'] === '') {
      $options['share_url'] = $current_page_url;
    }

    $share_url = '#';

    if ($options['name'] === 'x') {
      $share_url = 'https://twitter.com/intent/tweet?url=' . $options['share_url'];
      if ($options['share_text'] !== '') {
        $share_url .= '&text=' . $options['share_text'];
      }
    } else if ($options['name'] === 'facebook') {
      $share_url = 'https://www.facebook.com/sharer.php?u=' . $options['share_url'];
    }

  ?>
    <a class="social__link" href="<?php echo esc_attr($share_url); ?>" target="_blank">
    <?php

      /**
       * Icon
       */
      struninnuicards_digital_template_icon([
        'additional_wrapper_classes'  => 'social__icon',
        'icon'                        => $options['name']
      ]);

    ?>
    </a>
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnuicards_digital_template_social_link')) {
  /**
   * Prints social links template.
   * 
   * @since 1.0.0
   */
  function struninnuicards_digital_template_social_link($args = []) {
    $template = struninnuicards_digital_template_social_link_get($args);

    $template_allowed_html = [
      'a' => [
        'class'   => [],
        'href'    => [],
        'target'  => []
      ],
      'svg' => [
        'class' => []
      ],
      'use' => [
        'href' => []
      ]
    ];
    
    echo wp_kses($template, $template_allowed_html);
  }
}

?>